from __future__ import unicode_literals

import requests
import json
from django.conf import settings


class ASrouter(object):
    """Helper for Anonymizer Service communication handling."""
    # Anonymizer service endpoints
    anon_endpoint = False
    election_shard = "election/"
    list_votes_shard = "votes/"
    sign_votes_shard = "updatevotes/"

    def __init__(self):
        # Get all endpoints from the settings
        services_endpoints = getattr(settings,
                                     'EVOTE_SERVICES_ENDPOINTS',
                                     False)
        # If defined, try to set the anonymizer service base url
        if(services_endpoints):
            self.anon_endpoint = services_endpoints.get(
                'anonymizer', False)

    def build_election_url(self, election_id):
        """Method to build base endpoint URL for a
        given election ID.
        """
        url = False
        # Fetch the references from the Anonymizer Service
        if(self.anon_endpoint and self.election_shard):
            url = (self.anon_endpoint + self.election_shard +
                   str(election_id) + "/")

        else:
            raise Exception("Could not generate AS election ID")

        return url

    def fetch_votes(self, election_id=None, page=1):
        """Method to handle vote listing."""
        # List to hold the returned votes
        votes = []
        more = False
        # Sanity check
        if election_id is None:
            return (votes, more)

        base_url = self.build_election_url(election_id)

        if(base_url):
            # Build the endpoint URL
            url = base_url + self.list_votes_shard
            # Create the required GET data
            request_data = {'page': page}

            # Connect to the endpoint
            response = requests.get(url, request_data)

            # Check for valid response
            if response.status_code == 200:
                vote_list = response.json()
                if vote_list['count']:
                    for vote in vote_list['results']:
                        votes.append(vote)

                    # Check for next page
                    if vote_list['next'] is not None:
                        more = True

        return (votes, more)

    def sign_votes(self, election_id=None, vote_list=[]):
        """Method to send a batch of signed votes."""
        # Sanity check
        if (election_id is None or vote_list == []):
            return None

        # Return value
        update_status = None

        # Base URL
        base_url = self.build_election_url(election_id)

        if(base_url):
            # Build the endpoint URL
            url = base_url + self.sign_votes_shard
            # Create the required POST data
            request_data = {"vote_list": vote_list}

            # Connect to the endpoint
            response = requests.post(
                url,
                json.dumps(request_data),
                headers={'content-type': 'application/json'}
            )

            # Check for valid response
            if response.status_code == 200:
                update_status = response.json()

        return update_status
