from __future__ import unicode_literals

from mock import patch, Mock
from django.test import TestCase
from core import routers
from . import CounterServiceTestCase


class RoutersClassViewTest(TestCase):
    """ """

    # Setup the Test Case
    def setUp(self):
        self.router = routers.ASrouter()

    def test_router_init(self):
        """ """
        self.assertIsNotNone(self.router)

    def test_missing_settings(self):
        """ """
        with self.assertRaises(Exception):
            self.router.build_election_url(1)


class RoutersMethodsViewTest(CounterServiceTestCase, TestCase):
    """ """

    # Setup the Test Case
    def setUp(self):
        self.router = routers.ASrouter()
        self.votes = [
            "dummyvote1",
            "dummyvote2",
            "dummyvote3"
        ]
        self.dummy_response = {
            "count": True,
            "next": None,
            "results": self.votes
        }

    def test_build_election_url(self):
        """ """
        url = self.router.build_election_url(1)
        self.assertIsNotNone(url)

    def test_fetch_votes_no_id(self):
        """ """
        (votes, more) = self.router.fetch_votes()
        self.assertFalse(len(votes))
        self.assertFalse(more)

    @patch('core.routers.requests.get')
    def test_bad_as_request(self, mock_fn):
        """ """
        ret_obj = Mock()
        ret_obj.status_code = 400
        mock_fn.return_value = ret_obj
        (votes, more) = self.router.fetch_votes(1)
        self.assertFalse(len(votes))
        self.assertFalse(more)

    @patch('core.routers.requests.get')
    def test_success_as_request(self, mock_fn):
        """ """
        ret_obj = Mock()
        ret_obj.status_code = 200
        ret_obj.json.return_value = self.dummy_response
        mock_fn.return_value = ret_obj
        (votes, more) = self.router.fetch_votes(1)
        self.assertEquals(len(votes), len(self.votes))
        self.assertFalse(more)

    @patch('core.routers.requests.get')
    def test_paginated_as_request(self, mock_fn):
        """ """
        ret_obj = Mock()
        ret_obj.status_code = 200
        self.dummy_response['next'] = True
        ret_obj.json.return_value = self.dummy_response
        mock_fn.return_value = ret_obj
        (votes, more) = self.router.fetch_votes(1)
        self.assertEquals(len(votes), len(self.votes))
        self.assertTrue(more)

    # sign_votes unit tests
    def test_sign_votes_no_id(self):
        """ """
        status = self.router.sign_votes()
        self.assertIsNone(status)

    def test_sign_votes_no_list(self):
        """ """
        status = self.router.sign_votes(1)
        self.assertIsNone(status)

    @patch("core.routers.requests.post")
    def test_sign_votes_fail(self, mock_fn):
        """ """
        ret_obj = Mock()
        ret_obj.status_code = 400
        mock_fn.return_value = ret_obj
        status = self.router.sign_votes(1, self.votes)
        self.assertIsNone(status)

    @patch("core.routers.requests.post")
    def test_sign_votes_success(self, mock_fn):
        """ """
        ret_obj = Mock()
        ret_obj.status_code = 200
        ret_obj.json.return_value = True
        mock_fn.return_value = ret_obj
        status = self.router.sign_votes(1, self.votes)
        self.assertIsNotNone(status)
